Changelog
=========

Versions follow the `Semantic Versioning 2.0.0 <https://semver.org/>`_
standard.

.. Entry title format: django-overcomingbias-api 1.2.3 (release date)

.. Entry items:
.. Breaking Changes = backward-incompatible changes
.. Deprecations = functionality marked as deprecated
.. Features = Added new features
.. Improvements = Improvements to existing features
.. Bug Fixes
.. Improved Documentation
.. Trivial/Internal Changes

django-overcomingbias-api 0.1.0 (2022-04-13)
--------------------------------------------

Initial release.

See docs at `<https://django-overcomingbias-api.readthedocs.io/en/stable/>`_.
